@@ -98,8 +98,11 @@ bookmark_holder_new (CajaBookmark *bookmark,
 static void
 bookmark_holder_free (BookmarkHolder *bookmark_holder)
 {
+    if (g_signal_handler_is_connected(bookmark_holder->bookmark,
+                                      bookmark_holder->changed_handler_id)){
     g_signal_handler_disconnect (bookmark_holder->bookmark,
-                                 bookmark_holder->changed_handler_id);
+                                      bookmark_holder->changed_handler_id);
+    }
     g_object_unref (bookmark_holder->bookmark);
     g_free (bookmark_holder);
 }
@@ -535,7 +538,7 @@ action_about_caja_callback (GtkAction *action,
                                          "files and folders, both on "
                                          "your computer and online."),
                            "copyright", _("Copyright \xC2\xA9 1999-2009 The Nautilus authors\n"
-                                          "Copyright \xC2\xA9 2011-2016 The Caja authors"),
+                                          "Copyright \xC2\xA9 2011-2017 The Caja authors"),
                            "license", license_trans,
                            "wrap-license", TRUE,
                            "authors", authors,
